set linesize 140

/* 

Filename: table1.do

Project: "The Economic Impacts of Climate Change: Evidence from Agricultural Profits

and Random Fluctuations in Weather: Reply", Deschenes and Greenstone (2012)






Structure:

0. Set-up

1. Generate useful variables

2. Generate Table 1

	2a. Specification A (Columns 1a and 2a): With year effects

		2ai. Panel B: Tests of Significance of Weather Vars

		2aii. Panel A: Marginal Effects of Weather Vars w/ county-clustered SEs

		2aiii. Panel C: Tests of Equality of Weather Vars Across Dry & Irrigated Counties 

		2aiv. Panel A: Marginal Effects of Weather Vars w/ state-clustered SEs

	2b. 2b. Specification B (Columns 1b and 2b): With USDA-region specific year effects

		2bi. Panel B: Tests of Significance of Weather Vars

		2bii. Panel A: Marginal Effects of Weather Vars w/ county-clustered SEs

		2biii. Panel C: Tests of Equality of Weather Vars Across Dry & Irrigated Counties 

		2biv. Panel A: Marginal Effects of Weather Vars w/ state-clustered SEs

	2c. Specification C (Columns 1c and 2c): With Census-division specific year effects

		2ci. Panel B: Tests of Significance of Weather Vars

		2cii. Panel A: Marginal Effects of Weather Vars w/ county-clustered SEs

		2ciii. Panel C: Tests of Equality of Weather Vars Across Dry & Irrigated Counties 

		2civ. Panel A: Marginal Effects of Weather Vars w/ state-clustered SEs

	2d. Specification D (Columns 1d and 2d): With state specific year effects

		2di. Panel B: Tests of Significance of Weather Vars

		2dii. Panel A: Marginal Effects of Weather Vars w/ county-clustered SEs

		2diii. Panel C: Tests of Equality of Weather Vars Across Dry & Irrigated Counties 

		2div. Panel A: Marginal Effects of Weather Vars w/ state-clustered SEs

	2e. Panel B: Tests of significance for incremental interacted year effects

		2ei. Spec B against Spec A

		2eii. Spec C against Spec A

		2eiii. \Spec D against Spec A

*/



*************************************************************************************************************;

*************************************************************************************************************;

*** 0: Set-up ***********************************************************************************************;

#delimit;

set mem 200m;


*************************************************************************************************************;

*************************************************************************************************************;

*** 1: Generate variables ***********************************************************************************;


use DG_CORRECTED_SAMPLE_2012;

tab dry;

table year [aw=fland], c(mean y count y);
table year [aw=fland], c(mean dd89 count dd89 mean prcp count prcp);

summ dd89 [aw=fland];

gen dry_dd89=    (dry==1)*dd89;
gen dry_dd89_sq= (dry==1)*dd89*dd89;
gen dry_prcp=    (dry==1)*prcp;
gen dry_prcp_sq= (dry==1)*prcp*prcp;

gen irr_dd89=    (dry==0)*dd89;
gen irr_dd89_sq= (dry==0)*dd89*dd89;
gen irr_prcp=    (dry==0)*prcp;
gen irr_prcp_sq= (dry==0)*prcp*prcp;

summ dry_dd89 [aw=fland];
local m_dry_dd89=r(mean);
summ irr_dd89 [aw=fland];
local m_irr_dd89=r(mean);
summ dry_prcp [aw=fland];
local m_dry_prcp=r(mean);
summ irr_prcp [aw=fland];
local m_irr_prcp=r(mean);

save MASTER, replace;
clear;



*************************************************************************************************************;
*** 2. Generate Table 1 *************************************************************************************;

*************************************************************************************************************;

*************************************************************************************************************;

*** 2a. Specification A (Columns 1a and 2a): With year effects **********************************************;

		
use MASTER;
xi: areg y dry dry_dd89 dry_dd89_sq dry_prcp dry_prcp_sq 
irr_dd89 irr_dd89_sq irr_prcp irr_prcp_sq i.year x1-x9 [aweight=fland], a(fips) cluster(fips);
estimates store YYYY;




*************************************************************************************************************;

*** 2ai. Panel B: Tests of Significance of Weather Vars *****************************************************;



testparm dry_dd89* irr_dd89*;
testparm dry_dd89*;
testparm irr_dd89*;
testparm dry_prcp* irr_prcp*;
testparm dry_prcp*;
testparm irr_prcp*;
testparm _Iyear*;

gen ssr_R=e(rss);
summ ssr_R;




*************************************************************************************************************;

*** 2aii. Panel A: Marginal Effects of Weather Vars w/ county-clustered SEs *********************************;


di "1a: Marginal Effects, County-Clustered Standard Errors";
lincom 100*(dry_dd89 + 2*`m_dry_dd89'*dry_dd89_sq);
lincom 100*(irr_dd89 + 2*`m_irr_dd89'*irr_dd89_sq);
lincom dry_prcp + 2*`m_dry_prcp'*dry_prcp_sq;
lincom irr_prcp + 2*`m_irr_prcp'*irr_prcp_sq;


*************************************************************************************************************;

*** 2aiii. Panel C: Tests of Equality of Weather Vars Across Dry & Irrigated Counties  **********************;


test dry_dd89=irr_dd89;
test dry_dd89_sq=irr_dd89_sq;
testnl (_b[dry_dd89] + 2*`m_dry_dd89'*_b[dry_dd89_sq]) = (_b[irr_dd89] + 2*`m_irr_dd89'*_b[irr_dd89_sq]);
test dry_prcp=irr_prcp;
test dry_prcp_sq=irr_prcp_sq;
testnl (_b[dry_prcp] + 2*`m_dry_prcp'*_b[dry_prcp_sq]) = (_b[irr_prcp] + 2*`m_irr_prcp'*_b[irr_prcp_sq]);


*************************************************************************************************************;

*** 2aiv. Panel A: Marginal Effects of Weather Vars w/ state-clustered SEs  *********************************;


quiet xi: areg y dry dry_dd89 dry_dd89_sq dry_prcp dry_prcp_sq
irr_dd89 irr_dd89_sq irr_prcp irr_prcp_sq i.year x1-x9 [aweight=fland], a(fips) cluster(statefips);
estimates store YYYY_cluster_state;


di "1a: Marginal Effects, State-Clustered Standard Errors";
lincom 100*(dry_dd89 + 2*`m_dry_dd89'*dry_dd89_sq);
lincom 100*(irr_dd89 + 2*`m_irr_dd89'*irr_dd89_sq);
lincom dry_prcp + 2*`m_dry_prcp'*dry_prcp_sq;
lincom irr_prcp + 2*`m_irr_prcp'*irr_prcp_sq;

*************************************************************************************************************;

*** 2b. Specification B (Columns 1b and 2b): With USDA-region specific year effects *************************;

xi: areg y dry dry_dd89 dry_dd89_sq dry_prcp dry_prcp_sq
irr_dd89 irr_dd89_sq irr_prcp irr_prcp_sq i.uuyy x1-x9 [aweight=fland], a(fips) cluster(fips);
estimates store UUYY;


*************************************************************************************************************;

*** 2bi. Panel B: Tests of Significance of Weather Vars *****************************************************;



testparm dry_dd89* irr_dd89*;
testparm dry_dd89*;
testparm irr_dd89*;
testparm dry_prcp* irr_prcp*;
testparm dry_prcp*;
testparm irr_prcp*;         
testparm _Iuuyy*;

gen ssr_Ub=e(rss);
summ ssr_Ub;


*************************************************************************************************************;

*** 2bii. Panel A: Marginal Effects of Weather Vars w/ county-clustered SEs *********************************;


di "1b: Marginal Effects, County-Clustered Standard Errors";
lincom 100*(dry_dd89 + 2*`m_dry_dd89'*dry_dd89_sq);
lincom 100*(irr_dd89 + 2*`m_irr_dd89'*irr_dd89_sq);
lincom dry_prcp + 2*`m_dry_prcp'*dry_prcp_sq;
lincom irr_prcp + 2*`m_irr_prcp'*irr_prcp_sq;


*************************************************************************************************************;

*** 2biii. Panel C: Tests of Equality of Weather Vars Across Dry & Irrigated Counties  **********************;


test dry_dd89=irr_dd89;      
test dry_dd89_sq=irr_dd89_sq;
testnl (_b[dry_dd89] + 2*`m_dry_dd89'*_b[dry_dd89_sq]) = (_b[irr_dd89] + 2*`m_irr_dd89'*_b[irr_dd89_sq]);
test dry_prcp=irr_prcp;
test dry_prcp_sq=irr_prcp_sq;
testnl (_b[dry_prcp] + 2*`m_dry_prcp'*_b[dry_prcp_sq]) = (_b[irr_prcp] + 2*`m_irr_prcp'*_b[irr_prcp_sq]);


*************************************************************************************************************;

*** 2biv. Panel A: Marginal Effects of Weather Vars w/ state-clustered SEs  *********************************;


quiet xi: areg y dry dry_dd89 dry_dd89_sq dry_prcp dry_prcp_sq
irr_dd89 irr_dd89_sq irr_prcp irr_prcp_sq i.uuyy x1-x9 [aweight=fland], a(fips) cluster(statefips);
estimates store UUYY_cluster_state;


di "1b: Marginal Effects, State-Clustered Standard Errors";
lincom 100*(dry_dd89 + 2*`m_dry_dd89'*dry_dd89_sq);
lincom 100*(irr_dd89 + 2*`m_irr_dd89'*irr_dd89_sq);
lincom dry_prcp + 2*`m_dry_prcp'*dry_prcp_sq;
lincom irr_prcp + 2*`m_irr_prcp'*irr_prcp_sq;

*************************************************************************************************************;

*** 2c. Specification C (Columns 1c and 2c): With Census-division specific year effects *********************;


xi: areg y dry dry_dd89 dry_dd89_sq dry_prcp dry_prcp_sq
irr_dd89 irr_dd89_sq irr_prcp irr_prcp_sq i.ddyy x1-x9 [aweight=fland], a(fips) cluster(fips);
estimates store DDYY;


*************************************************************************************************************;

*** 2ci. Panel B: Tests of Significance of Weather Vars *****************************************************;



testparm dry_dd89* irr_dd89*;
testparm dry_dd89*;
testparm irr_dd89*;
testparm dry_prcp* irr_prcp*;
testparm dry_prcp*;
testparm irr_prcp*;         
testparm _Iddyy*;

gen ssr_Uc=e(rss);
summ ssr_Uc;


*************************************************************************************************************;

*** 2cii. Panel A: Marginal Effects of Weather Vars w/ county-clustered SEs *********************************;


di "1c: Marginal Effects, County-Clustered Standard Errors";
lincom 100*(dry_dd89 + 2*`m_dry_dd89'*dry_dd89_sq);
lincom 100*(irr_dd89 + 2*`m_irr_dd89'*irr_dd89_sq);
lincom dry_prcp + 2*`m_dry_prcp'*dry_prcp_sq;
lincom irr_prcp + 2*`m_irr_prcp'*irr_prcp_sq;


*************************************************************************************************************;

*** 2ciii. Panel C: Tests of Equality of Weather Vars Across Dry & Irrigated Counties  **********************;


test dry_dd89=irr_dd89;      
test dry_dd89_sq=irr_dd89_sq;
testnl (_b[dry_dd89] + 2*`m_dry_dd89'*_b[dry_dd89_sq]) = (_b[irr_dd89] + 2*`m_irr_dd89'*_b[irr_dd89_sq]);
test dry_prcp=irr_prcp;
test dry_prcp_sq=irr_prcp_sq;
testnl (_b[dry_prcp] + 2*`m_dry_prcp'*_b[dry_prcp_sq]) = (_b[irr_prcp] + 2*`m_irr_prcp'*_b[irr_prcp_sq]);


*************************************************************************************************************;

*** 2civ. Panel A: Marginal Effects of Weather Vars w/ state-clustered SEs  *********************************;


quiet xi: areg y dry dry_dd89 dry_dd89_sq dry_prcp dry_prcp_sq
irr_dd89 irr_dd89_sq irr_prcp irr_prcp_sq i.ddyy x1-x9 [aweight=fland], a(fips) cluster(statefips);
estimates store DDYY_cluster_state;

di "1c: Marginal Effects, State-Clustered Standard Errors";
lincom 100*(dry_dd89 + 2*`m_dry_dd89'*dry_dd89_sq);
lincom 100*(irr_dd89 + 2*`m_irr_dd89'*irr_dd89_sq);
lincom dry_prcp + 2*`m_dry_prcp'*dry_prcp_sq;
lincom irr_prcp + 2*`m_irr_prcp'*irr_prcp_sq;

*************************************************************************************************************;

*** 2d. Specification D (Columns 1d and 2d): With state specific year effects *******************************;

xi: areg y dry dry_dd89 dry_dd89_sq dry_prcp dry_prcp_sq
irr_dd89 irr_dd89_sq irr_prcp irr_prcp_sq i.ssyy x1-x9 [aweight=fland], a(fips) cluster(fips);
estimates store SSYY;


*************************************************************************************************************;

*** 2di. Panel B: Tests of Significance of Weather Vars *****************************************************;



testparm dry_dd89* irr_dd89*;
testparm dry_dd89*;
testparm irr_dd89*;
testparm dry_prcp* irr_prcp*;
testparm dry_prcp*;
testparm irr_prcp*;         
testparm _Issyy*;

gen ssr_Ud=e(rss);
summ ssr_Ud;


*************************************************************************************************************;

*** 2dii. Panel A: Marginal Effects of Weather Vars w/ county-clustered SEs *********************************;


di "1d: Marginal Effects, County-Clustered Standard Errors";
lincom 100*(dry_dd89 + 2*`m_dry_dd89'*dry_dd89_sq);
lincom 100*(irr_dd89 + 2*`m_irr_dd89'*irr_dd89_sq);
lincom dry_prcp + 2*`m_dry_prcp'*dry_prcp_sq;
lincom irr_prcp + 2*`m_irr_prcp'*irr_prcp_sq;


*************************************************************************************************************;

*** 2diii. Panel C: Tests of Equality of Weather Vars Across Dry & Irrigated Counties  **********************;


test dry_dd89=irr_dd89;      
test dry_dd89_sq=irr_dd89_sq;
testnl (_b[dry_dd89] + 2*`m_dry_dd89'*_b[dry_dd89_sq]) = (_b[irr_dd89] + 2*`m_irr_dd89'*_b[irr_dd89_sq]);
test dry_prcp=irr_prcp;
test dry_prcp_sq=irr_prcp_sq;
testnl (_b[dry_prcp] + 2*`m_dry_prcp'*_b[dry_prcp_sq]) = (_b[irr_prcp] + 2*`m_irr_prcp'*_b[irr_prcp_sq]);


*************************************************************************************************************;

*** 2div. Panel A: Marginal Effects of Weather Vars w/ state-clustered SEs  *********************************;


quiet xi: areg y dry dry_dd89 dry_dd89_sq dry_prcp dry_prcp_sq
irr_dd89 irr_dd89_sq irr_prcp irr_prcp_sq i.ssyy x1-x9 [aweight=fland], a(fips) cluster(statefips);
estimates store SSYY_cluster_state;

di "1d: Marginal Effects, State-Clustered Standard Errors";
lincom 100*(dry_dd89 + 2*`m_dry_dd89'*dry_dd89_sq);
lincom 100*(irr_dd89 + 2*`m_irr_dd89'*irr_dd89_sq);
lincom dry_prcp + 2*`m_dry_prcp'*dry_prcp_sq;
lincom irr_prcp + 2*`m_irr_prcp'*irr_prcp_sq;

*************************************************************************************************************;

*** 2e. Panel B: Compute F-stats and p-values for incremental interacted year effects  **********************;


di "Compute F-statistics and p-values for incremental interacted year effects, i.e. spec b-d against spec a";


*************************************************************************************************************;

*** 2ei. Spec B against Spec A  *****************************************************************************;


gen F=((ssr_R-ssr_Ub)/(27-3)) / (ssr_Ub/(9364-2341-44));
gen pvalue=Ftail((27-3),(9364-2341-44),F);
summ F pvalue;
drop F pvalue;


*************************************************************************************************************;

*** 2eii. Spec C against Spec A  ****************************************************************************;


gen F=((ssr_R-ssr_Uc)/(27-3)) / (ssr_Uc/(9364-2341-44));
gen pvalue=Ftail((27-3),(9364-2341-44),F);
summ F pvalue;
drop F pvalue;


*************************************************************************************************************;

*** 2eiii. Spec D against Spec A  ***************************************************************************;


gen F=((ssr_R-ssr_Ud)/(144-3)) / (ssr_Ud/(9364-2341-160));
gen pvalue=Ftail((144-3),(9364-2341-160),F);
summ F pvalue;
drop F pvalue;
clear;

*************************************************************************************************************;

*** Clean-up  ***********************************************************************************************;

! \rm *.o*;
! \rm MASTER.dta;
