#delimit;

set mem 200m;
set linesize 140;

use REPLICATE_FHRS;

tab year;

    * Program adapted from code provided by FHRS;

    *************************************************************************************************;
    * Part 2: regression results;
    *************************************************************************************************;
    display("###########################################################################################");
    display("Raw Regression Results");
    display("###########################################################################################");
    
    /** 1a **/
    xi: areg y dry_dd89dm dry_dd89dm_sq dry_prec dry_prec_sq irr_dd89dm irr_dd89dm_sq irr_prec irr_prec_sq
               dry x2-x9 i.year [aweight=fland], a(fips) cluster(fips);
    estimates store YYYY;

    xi: areg y dry_dd89dm dry_dd89dm_sq dry_prec dry_prec_sq irr_dd89dm irr_dd89dm_sq irr_prec irr_prec_sq
               dry x2-x9 i.year [aweight=fland], a(fips) cluster(statefips);
    estimates store YYYY_cluster_state;


    /** 1b **/
    xi: areg y dry_dd89dm dry_dd89dm_sq dry_prec dry_prec_sq irr_dd89dm irr_dd89dm_sq irr_prec irr_prec_sq
               dry x2-x9 i.uuyy [aweight=fland], a(fips) cluster(fips);
    estimates store UUYY;

    xi: areg y dry_dd89dm dry_dd89dm_sq dry_prec dry_prec_sq irr_dd89dm irr_dd89dm_sq irr_prec irr_prec_sq
               dry x2-x9 i.uuyy [aweight=fland], a(fips) cluster(statefips);
    estimates store UUYY_cluster_state;


    /** 1c **/
    xi: areg y dry_dd89dm dry_dd89dm_sq dry_prec dry_prec_sq irr_dd89dm irr_dd89dm_sq irr_prec irr_prec_sq
               dry x2-x9 i.ddyy [aweight=fland], a(fips) cluster(fips);
    estimates store DDYY;

    xi: areg y dry_dd89dm dry_dd89dm_sq dry_prec dry_prec_sq irr_dd89dm irr_dd89dm_sq irr_prec irr_prec_sq
               dry x2-x9 i.ddyy [aweight=fland], a(fips) cluster(statefips);
    estimates store DDYY_cluster_state;


    /** 1d **/
    xi: areg y dry_dd89dm dry_dd89dm_sq dry_prec dry_prec_sq irr_dd89dm irr_dd89dm_sq irr_prec irr_prec_sq
               dry x2-x9 i.ssyy [aweight=fland], a(fips) cluster(fips);
    estimates store SSYY;

    xi: areg y dry_dd89dm dry_dd89dm_sq dry_prec dry_prec_sq irr_dd89dm irr_dd89dm_sq irr_prec irr_prec_sq
               dry x2-x9 i.ssyy [aweight=fland], a(fips) cluster(statefips);
    estimates store SSYY_cluster_state;



    *************************************************************************************************;
    * Part 4: climate change impacts;
    *************************************************************************************************;
    display("###########################################################################################");
    display("Climate Change Impacts");
    display("###########################################################################################");

    *************************************************************************************************;
    display("*******************************************************************************************");
    display("Column b1: regression with our reconstructed variable of DG - Hadley II");
    * column b1: regression with our reconstructed variable of DG - Hadley II;
    * derive change in climate variables under global warming;
    gen d_dry_dd89dmH2    = (dry==1)*d_dday8_32dmH2;
    gen d_dry_dd89dmH2_sq = (dry==1)*d_dday8_32dmH2_sq;
    gen d_dry_precH2      = (dry==1)*d_precH2;
    gen d_dry_precH2_sq   = (dry==1)*d_precH2_sq;
    gen d_irr_dd89dmH2    = (dry==0)*d_dday8_32dmH2;
    gen d_irr_dd89dmH2_sq = (dry==0)*d_dday8_32dmH2_sq;
    gen d_irr_precH2      = (dry==0)*d_precH2;
    gen d_irr_precH2_sq   = (dry==0)*d_precH2_sq;

    summ d_dry* d_irr* [aw=fland];

    local irrigList dry irr;
    local varList dd89dmH2 dd89dmH2_sq precH2 precH2_sq;
    foreach i of local irrigList {;
        foreach v of local varList {;
            qui egen hilf = total(d_`i'_`v'*fland/1000000000), by(year);
            qui summ hilf;
            local diff_`i'_`v' = r(mean);
            drop hilf;
        };
    };

    /** 1a **/
    estimates restore YYYY;
    lincom _b[dry_dd89dm] * `diff_dry_dd89dmH2' + _b[dry_dd89dm_sq] * `diff_dry_dd89dmH2_sq' + _b[dry_prec] * `diff_dry_precH2' + _b[dry_prec_sq] * `diff_dry_precH2_sq'
         + _b[irr_dd89dm] * `diff_irr_dd89dmH2' + _b[irr_dd89dm_sq] * `diff_irr_dd89dmH2_sq' + _b[irr_prec] * `diff_irr_precH2' + _b[irr_prec_sq] * `diff_irr_precH2_sq' ;

    estimates restore YYYY_cluster_state;
    lincom _b[dry_dd89dm] * `diff_dry_dd89dmH2' + _b[dry_dd89dm_sq] * `diff_dry_dd89dmH2_sq' + _b[dry_prec] * `diff_dry_precH2' + _b[dry_prec_sq] * `diff_dry_precH2_sq'
         + _b[irr_dd89dm] * `diff_irr_dd89dmH2' + _b[irr_dd89dm_sq] * `diff_irr_dd89dmH2_sq' + _b[irr_prec] * `diff_irr_precH2' + _b[irr_prec_sq] * `diff_irr_precH2_sq' ;


    /** 1a **/
    estimates restore UUYY;
    lincom _b[dry_dd89dm] * `diff_dry_dd89dmH2' + _b[dry_dd89dm_sq] * `diff_dry_dd89dmH2_sq' + _b[dry_prec] * `diff_dry_precH2' + _b[dry_prec_sq] * `diff_dry_precH2_sq'
         + _b[irr_dd89dm] * `diff_irr_dd89dmH2' + _b[irr_dd89dm_sq] * `diff_irr_dd89dmH2_sq' + _b[irr_prec] * `diff_irr_precH2' + _b[irr_prec_sq] * `diff_irr_precH2_sq' ;

    estimates restore UUYY_cluster_state;
    lincom _b[dry_dd89dm] * `diff_dry_dd89dmH2' + _b[dry_dd89dm_sq] * `diff_dry_dd89dmH2_sq' + _b[dry_prec] * `diff_dry_precH2' + _b[dry_prec_sq] * `diff_dry_precH2_sq'
         + _b[irr_dd89dm] * `diff_irr_dd89dmH2' + _b[irr_dd89dm_sq] * `diff_irr_dd89dmH2_sq' + _b[irr_prec] * `diff_irr_precH2' + _b[irr_prec_sq] * `diff_irr_precH2_sq' ;


    /** 1c **/
    estimates restore DDYY;
    lincom _b[dry_dd89dm] * `diff_dry_dd89dmH2' + _b[dry_dd89dm_sq] * `diff_dry_dd89dmH2_sq' + _b[dry_prec] * `diff_dry_precH2' + _b[dry_prec_sq] * `diff_dry_precH2_sq'
         + _b[irr_dd89dm] * `diff_irr_dd89dmH2' + _b[irr_dd89dm_sq] * `diff_irr_dd89dmH2_sq' + _b[irr_prec] * `diff_irr_precH2' + _b[irr_prec_sq] * `diff_irr_precH2_sq' ;

    estimates restore DDYY_cluster_state;
    lincom _b[dry_dd89dm] * `diff_dry_dd89dmH2' + _b[dry_dd89dm_sq] * `diff_dry_dd89dmH2_sq' + _b[dry_prec] * `diff_dry_precH2' + _b[dry_prec_sq] * `diff_dry_precH2_sq'
         + _b[irr_dd89dm] * `diff_irr_dd89dmH2' + _b[irr_dd89dm_sq] * `diff_irr_dd89dmH2_sq' + _b[irr_prec] * `diff_irr_precH2' + _b[irr_prec_sq] * `diff_irr_precH2_sq' ;


    /** 1d **/
    estimates restore SSYY;
    lincom _b[dry_dd89dm] * `diff_dry_dd89dmH2' + _b[dry_dd89dm_sq] * `diff_dry_dd89dmH2_sq' + _b[dry_prec] * `diff_dry_precH2' + _b[dry_prec_sq] * `diff_dry_precH2_sq'
         + _b[irr_dd89dm] * `diff_irr_dd89dmH2' + _b[irr_dd89dm_sq] * `diff_irr_dd89dmH2_sq' + _b[irr_prec] * `diff_irr_precH2' + _b[irr_prec_sq] * `diff_irr_precH2_sq' ;

    estimates restore SSYY_cluster_state;
    lincom _b[dry_dd89dm] * `diff_dry_dd89dmH2' + _b[dry_dd89dm_sq] * `diff_dry_dd89dmH2_sq' + _b[dry_prec] * `diff_dry_precH2' + _b[dry_prec_sq] * `diff_dry_precH2_sq'
         + _b[irr_dd89dm] * `diff_irr_dd89dmH2' + _b[irr_dd89dm_sq] * `diff_irr_dd89dmH2_sq' + _b[irr_prec] * `diff_irr_precH2' + _b[irr_prec_sq] * `diff_irr_precH2_sq' ;

clear;

! \rm *.o*;

