#delimit;

set linesize 140;
set mem 200m;

*************************************************************************************************************;

*************************************************************************************************************;

*** 1. Generate Table 2, Row 5 ******************************************************************************;
*************************************************************************************************************;

*************************************************************************************************************;

*** 1a: Generate local variables ****************************************************************************;

use DG_CORRECTED_SAMPLE_2012;

table year [aw=fland], c(mean y count y);
table year [aw=fland], c(mean dd89 count dd89 mean prcp count prcp);
save MASTER, replace;
clear;


*************************************************************************************************************;

*** 1ai. Specification A: With year effects *****************************************************************;

use MASTER;
* County-clustered SEs;
xi: areg y dry dd89 dd89_sq prcp prcp_sq i.year x1-x9 [aw=fland], a(fips) cluster(fips);
estimates store YYYY;
testparm dd89*;
testparm prcp*;
testparm _Iyear*;

* State-clustered SEs;
quiet xi: areg y dry dd89 dd89_sq prcp prcp_sq i.year x1-x9 [aw=fland], a(fips) cluster(statefips);
estimates store YYYY_cluster_state;
clear;

*************************************************************************************************************;

*** 1aii. Specification B: With USDA-region specific year effects *******************************************;

use MASTER;
* County-clustered SEs;
xi: areg y dry dd89 dd89_sq prcp prcp_sq i.uuyy x1-x9 [aw=fland], a(fips) cluster(fips);
estimates store UUYY;
testparm dd89*;
testparm prcp*;
testparm _Iuuyy*;

* State-clustered SEs;
quiet xi: areg y dry dd89 dd89_sq prcp prcp_sq i.uuyy x1-x9 [aw=fland], a(fips) cluster(statefips);
estimates store UUYY_cluster_state;
clear;


*************************************************************************************************************;

*** 1aiii. Specification C: With Census-division specific year effects **************************************;

use MASTER;
* County-clustered SEs;
xi: areg y dry dd89 dd89_sq prcp prcp_sq i.ddyy x1-x9 [aw=fland], a(fips) cluster(fips);
estimates store DDYY;
testparm dd89*;
testparm prcp*;
testparm _Iddyy*;

* State-clustered SEs;
quiet xi: areg y dry dry dd89 dd89_sq prcp prcp_sq i.ddyy x1-x9 [aw=fland], a(fips) cluster(statefips);
estimates store DDYY_cluster_state;
clear;


*************************************************************************************************************;

*** 1aiv. Specification D: With state specific year effects *************************************************;

use MASTER;
* County-clustered SEs;
xi: areg y dry dry dd89 dd89_sq prcp prcp_sq i.ssyy x1-x9 [aw=fland], a(fips) cluster(fips);
estimates store SSYY;
testparm dd89*;
testparm prcp*;
testparm _Issyy*;

* State-clustered SEs;
quiet xi: areg y dry dry dd89 dd89_sq prcp prcp_sq i.ssyy x1-x9 [aw=fland], a(fips) cluster(statefips);
estimates store SSYY_cluster_state;
clear;

*************************************************************************************************************;

*************************************************************************************************************;

*** 1b. Reweighted predicted change in climate **************************************************************;

use MASTER;                  

egen sb_=sum(fland*ccsm_d_dd89/1000000000), by(year);
summ sb_;
local d_ccsm_dd89=r(mean);
drop sb_;

egen sb_=sum(fland*ccsm_d_dd89_sq/1000000000), by(year);
summ sb_;
local d_ccsm_dd89_sq=r(mean);
drop sb_;

egen sb_=sum(fland*ccsm_d_prcp/1000000000), by(year); 
summ sb_;
local d_ccsm_prcp=r(mean);
drop sb_;                    

egen sb_=sum(fland*ccsm_d_prcp_sq/1000000000), by(year);
summ sb_;                    
local d_ccsm_prcp_sq=r(mean);  
drop sb_;          


*************************************************************************************************************;

*************************************************************************************************************;

*** 1c. Calculate Average Annual Aggregate Farm Profits *****************************************************;

gen pi = y*fland;
bys year (fips): egen agg_pi = total(pi);
egen avg_agg_pi = mean(agg_pi);
label var avg_agg_pi "Average annual aggregate farm profits in sample";


*************************************************************************************************************;

*************************************************************************************************************;

*** 1d. Predicted Impact on Aggregate Farm Profits **********************************************************;

***		Notes: $2002 BIL.  See di statement for panel / row / column information ****************************;

*** 	First reported estimate has county-clustered std error **********************************************;

*** 	Second reported estimate has state-clustered std error **********************************************;

***		All estimates are derived under the CCSM 3 A2 climate model *****************************************;

*************************************************************************************************************;

*************************************************************************************************************;

*** 1di. Table 2, Row 5, Column 1a *****************************************************************;

di "*********************************************************************";
di "*********************************************************************";
di "Table 2, Row 5, Column 1a";
estimates restore YYYY;
lincom _b[dd89]*`d_ccsm_dd89' + _b[dd89_sq]*`d_ccsm_dd89_sq' + _b[prcp]*`d_ccsm_prcp' + _b[prcp_sq]*`d_ccsm_prcp_sq' ;
gen pp_1a=r(estimate);
gen secc_1a=r(se);
gen perc_1a=r(estimate)*100000000000/avg_agg_pi;

estimates restore YYYY_cluster_state;
lincom _b[dd89]*`d_ccsm_dd89' + _b[dd89_sq]*`d_ccsm_dd89_sq' + _b[prcp]*`d_ccsm_prcp' + _b[prcp_sq]*`d_ccsm_prcp_sq' ;
gen sesc_1a=r(se);

*************************************************************************************************************;

*** 1dii. Table 2, Row 5, Column 1b ****************************************************************;

di "*********************************************************************";
di "*********************************************************************";
di "Table 2, Row 5, Column 1b";
estimates restore UUYY;
lincom _b[dd89]*`d_ccsm_dd89' + _b[dd89_sq]*`d_ccsm_dd89_sq' + _b[prcp]*`d_ccsm_prcp' + _b[prcp_sq]*`d_ccsm_prcp_sq' ;
gen pp_1b=r(estimate);
gen secc_1b=r(se);
gen perc_1b=r(estimate)*100000000000/avg_agg_pi;

estimates restore UUYY_cluster_state;
lincom _b[dd89]*`d_ccsm_dd89' + _b[dd89_sq]*`d_ccsm_dd89_sq' + _b[prcp]*`d_ccsm_prcp' + _b[prcp_sq]*`d_ccsm_prcp_sq' ;
gen sesc_1b=r(se);

*************************************************************************************************************;

*** 1diii. Table 2, Row 5, Column 1c ***************************************************************;

di "*********************************************************************";
di "*********************************************************************";
di "Table 2, Row 5, Column 1c";
estimates restore DDYY;
lincom _b[dd89]*`d_ccsm_dd89' + _b[dd89_sq]*`d_ccsm_dd89_sq' + _b[prcp]*`d_ccsm_prcp' + _b[prcp_sq]*`d_ccsm_prcp_sq' ;
gen pp_1c=r(estimate);
gen secc_1c=r(se);
gen perc_1c=r(estimate)*100000000000/avg_agg_pi;

estimates restore DDYY_cluster_state;
lincom _b[dd89]*`d_ccsm_dd89' + _b[dd89_sq]*`d_ccsm_dd89_sq' + _b[prcp]*`d_ccsm_prcp' + _b[prcp_sq]*`d_ccsm_prcp_sq' ;
gen sesc_1c=r(se);

*************************************************************************************************************;

*** 1div. Table 2, Row 5, Column 1d ****************************************************************;

di "*********************************************************************";
di "*********************************************************************";
di "Table 2, Row 5, Column 1d";
estimates restore SSYY;
lincom _b[dd89]*`d_ccsm_dd89' + _b[dd89_sq]*`d_ccsm_dd89_sq' + _b[prcp]*`d_ccsm_prcp' + _b[prcp_sq]*`d_ccsm_prcp_sq' ;
gen pp_1d=r(estimate);
gen secc_1d=r(se);
gen perc_1d=r(estimate)*100000000000/avg_agg_pi;

estimates restore SSYY_cluster_state;
lincom _b[dd89]*`d_ccsm_dd89' + _b[dd89_sq]*`d_ccsm_dd89_sq' + _b[prcp]*`d_ccsm_prcp' + _b[prcp_sq]*`d_ccsm_prcp_sq' ;
gen sesc_1d=r(se);

*************************************************************************************************************;


* Summary Table: Estimates, specifications a-d;
summ pp*, sep(0);
summ secc*, sep(0);
summ sesc*, sep(0);
summ perc*, sep(0);
drop pp* secc* sesc* per*;

clear;


! \rm MASTER.dta;
! \rm *.o*;

